@@ -12,7 +12,8 @@ import evalml.problem_types
 import evalml.utils
 import evalml.data_checks
 from evalml.automl import AutoMLSearch, search
-from evalml.utils import print_info
+from evalml.utils import print_info, update_checker
+
 with warnings.catch_warnings():
     warnings.simplefilter("ignore", FutureWarning)
     warnings.simplefilter("ignore", DeprecationWarning)
@@ -20,4 +21,4 @@ with warnings.catch_warnings():
 warnings.filterwarnings("ignore", category=FutureWarning)
 warnings.filterwarnings("ignore", category=DeprecationWarning)
 
-__version__ = '0.25.0'
+__version__ = "0.28.0"
