@@ -1,41 +1,42 @@
 from evalml.utils import import_or_raise, jupyter_check
 
 
-class SearchIterationPlot():
-    def __init__(self, data, show_plot=True):
-        self._go = import_or_raise("plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects")
+class SearchIterationPlot:
+    def __init__(self, results, objective):
+        self._go = import_or_raise(
+            "plotly.graph_objects",
+            error_msg="Cannot find dependency plotly.graph_objects",
+        )
 
         if jupyter_check():
             import_or_raise("ipywidgets", warning=True)
 
-        self.data = data
         self.best_score_by_iter_fig = None
         self.curr_iteration_scores = list()
         self.best_iteration_scores = list()
 
-        title = 'Pipeline Search: Iteration vs. {}<br><sub>Gray marker indicates the score at current iteration</sub>'.format(self.data.objective.name)
+        title = "Pipeline Search: Iteration vs. {}<br><sub>Gray marker indicates the score at current iteration</sub>".format(
+            objective.name
+        )
         data = [
-            self._go.Scatter(x=[], y=[], mode='lines+markers', name='Best Score'),
-            self._go.Scatter(x=[], y=[], mode='markers', name='Iter score', marker={'color': 'gray'})
+            self._go.Scatter(x=[], y=[], mode="lines+markers", name="Best Score"),
+            self._go.Scatter(
+                x=[], y=[], mode="markers", name="Iter score", marker={"color": "gray"}
+            ),
         ]
         layout = {
-            'title': title,
-            'xaxis': {
-                'title': 'Iteration',
-                'rangemode': 'tozero'
-            },
-            'yaxis': {
-                'title': 'Score'
-            }
+            "title": title,
+            "xaxis": {"title": "Iteration", "rangemode": "tozero"},
+            "yaxis": {"title": "Score"},
         }
         self.best_score_by_iter_fig = self._go.FigureWidget(data, layout)
         self.best_score_by_iter_fig.update_layout(showlegend=False)
-        self.update()
+        self.update(results, objective)
 
-    def update(self):
-        if len(self.data.results['search_order']) > 0 and len(self.data.results['pipeline_results']) > 0:
-            iter_idx = self.data.results['search_order']
-            pipeline_res = self.data.results['pipeline_results']
+    def update(self, results, objective):
+        if len(results["search_order"]) > 0 and len(results["pipeline_results"]) > 0:
+            iter_idx = results["search_order"]
+            pipeline_res = results["pipeline_results"]
             iter_scores = [pipeline_res[i]["mean_cv_score"] for i in iter_idx]
 
             iter_score_pairs = zip(iter_idx, iter_scores)
@@ -50,8 +51,12 @@ class SearchIterationPlot():
                     best_iteration_scores.append(score)
                     curr_best = score
                 else:
-                    if self.data.objective.greater_is_better and score > curr_best \
-                            or not self.data.objective.greater_is_better and score < curr_best:
+                    if (
+                        objective.greater_is_better
+                        and score > curr_best
+                        or not objective.greater_is_better
+                        and score < curr_best
+                    ):
                         best_iteration_scores.append(score)
                         curr_best = score
                     else:
@@ -68,17 +73,20 @@ class SearchIterationPlot():
 
 
 class PipelineSearchPlots:
-    """Plots for the AutoMLSearch class.
-    """
+    """Plots for the AutoMLSearch class."""
 
-    def __init__(self, data):
+    def __init__(self, results, objective):
         """Make plots for the AutoMLSearch class.
 
         Arguments:
             data (AutoMLSearch): Automated pipeline search object
         """
-        self._go = import_or_raise("plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects")
-        self.data = data
+        self._go = import_or_raise(
+            "plotly.graph_objects",
+            error_msg="Cannot find dependency plotly.graph_objects",
+        )
+        self.results = results
+        self.objective = objective
 
     def search_iteration_plot(self, interactive_plot=False):
         """Shows a plot of the best score at each iteration using data gathered during training.
@@ -87,11 +95,13 @@ class PipelineSearchPlots:
             plot
         """
         if not interactive_plot:
-            plot_obj = SearchIterationPlot(self.data)
+            plot_obj = SearchIterationPlot(self.results, self.objective)
             return self._go.Figure(plot_obj.best_score_by_iter_fig)
         try:
-            ipython_display = import_or_raise("IPython.display", error_msg="Cannot find dependency IPython.display")
-            plot_obj = SearchIterationPlot(self.data)
+            ipython_display = import_or_raise(
+                "IPython.display", error_msg="Cannot find dependency IPython.display"
+            )
+            plot_obj = SearchIterationPlot(self.results, self.objective)
             ipython_display.display(plot_obj.best_score_by_iter_fig)
             return plot_obj
         except ImportError:
