@@ -1,9 +1,8 @@
-
 from evalml.data_checks import (
     DataCheck,
     DataCheckError,
     DataCheckMessageCode,
-    DataCheckWarning
+    DataCheckWarning,
 )
 from evalml.utils import infer_feature_types
 
@@ -25,13 +24,23 @@ class ClassImbalanceDataCheck(DataCheck):
             num_cv_folds (int): The number of cross-validation folds. Must be positive. Choose 0 to ignore this warning.
         """
         if threshold <= 0 or threshold > 0.5:
-            raise ValueError("Provided threshold {} is not within the range (0, 0.5]".format(threshold))
+            raise ValueError(
+                "Provided threshold {} is not within the range (0, 0.5]".format(
+                    threshold
+                )
+            )
         self.threshold = threshold
         if min_samples <= 0:
-            raise ValueError("Provided value min_samples {} is not greater than 0".format(min_samples))
+            raise ValueError(
+                "Provided value min_samples {} is not greater than 0".format(
+                    min_samples
+                )
+            )
         self.min_samples = min_samples
         if num_cv_folds < 0:
-            raise ValueError("Provided number of CV folds {} is less than 0".format(num_cv_folds))
+            raise ValueError(
+                "Provided number of CV folds {} is less than 0".format(num_cv_folds)
+            )
         self.cv_folds = num_cv_folds * 2
 
     def validate(self, X, y):
@@ -68,11 +77,7 @@ class ClassImbalanceDataCheck(DataCheck):
                                                                    "details": {"target_values": [0]}}],\
                                                      "actions": []}
         """
-        results = {
-            "warnings": [],
-            "errors": [],
-            "actions": []
-        }
+        results = {"warnings": [], "errors": [], "actions": []}
 
         y = infer_feature_types(y)
 
@@ -84,27 +89,46 @@ class ClassImbalanceDataCheck(DataCheck):
         if len(below_threshold_folds):
             below_threshold_values = below_threshold_folds.index.tolist()
             error_msg = "The number of instances of these targets is less than 2 * the number of cross folds = {} instances: {}"
-            DataCheck._add_message(DataCheckError(message=error_msg.format(self.cv_folds, below_threshold_values),
-                                                  data_check_name=self.name,
-                                                  message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
-                                                  details={"target_values": below_threshold_values}), results)
+            DataCheck._add_message(
+                DataCheckError(
+                    message=error_msg.format(self.cv_folds, below_threshold_values),
+                    data_check_name=self.name,
+                    message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
+                    details={"target_values": below_threshold_values},
+                ),
+                results,
+            )
         counts = fold_counts / (fold_counts + fold_counts.values[0])
         below_threshold = counts.where(counts < self.threshold).dropna()
         # if there are items that occur less than the threshold, add them to the list of results
         if len(below_threshold):
             below_threshold_values = below_threshold.index.tolist()
             warning_msg = "The following labels fall below {:.0f}% of the target: {}"
-            DataCheck._add_message(DataCheckWarning(message=warning_msg.format(self.threshold * 100, below_threshold_values),
-                                                    data_check_name=self.name,
-                                                    message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
-                                                    details={"target_values": below_threshold_values}), results)
+            DataCheck._add_message(
+                DataCheckWarning(
+                    message=warning_msg.format(
+                        self.threshold * 100, below_threshold_values
+                    ),
+                    data_check_name=self.name,
+                    message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
+                    details={"target_values": below_threshold_values},
+                ),
+                results,
+            )
         sample_counts = fold_counts.where(fold_counts < self.min_samples).dropna()
         if len(below_threshold) and len(sample_counts):
             sample_count_values = sample_counts.index.tolist()
             severe_imbalance = [v for v in sample_count_values if v in below_threshold]
             warning_msg = "The following labels in the target have severe class imbalance because they fall under {:.0f}% of the target and have less than {} samples: {}"
-            DataCheck._add_message(DataCheckWarning(message=warning_msg.format(self.threshold * 100, self.min_samples, severe_imbalance),
-                                                    data_check_name=self.name,
-                                                    message_code=DataCheckMessageCode.CLASS_IMBALANCE_SEVERE,
-                                                    details={"target_values": severe_imbalance}), results)
+            DataCheck._add_message(
+                DataCheckWarning(
+                    message=warning_msg.format(
+                        self.threshold * 100, self.min_samples, severe_imbalance
+                    ),
+                    data_check_name=self.name,
+                    message_code=DataCheckMessageCode.CLASS_IMBALANCE_SEVERE,
+                    details={"target_values": severe_imbalance},
+                ),
+                results,
+            )
         return results
