@@ -1,8 +1,7 @@
-
 from evalml.data_checks import (
     DataCheck,
     DataCheckMessageCode,
-    DataCheckWarning
+    DataCheckWarning,
 )
 from evalml.utils import infer_feature_types
 
@@ -30,22 +29,29 @@ class MulticollinearityDataCheck(DataCheck):
             dict: dict with a DataCheckWarning if there are any potentially multicollinear columns.
 
         """
-        results = {
-            "warnings": [],
-            "errors": [],
-            "actions": []
-        }
+        results = {"warnings": [], "errors": [], "actions": []}
 
         X = infer_feature_types(X)
         mutual_info_df = X.ww.mutual_information()
         if mutual_info_df.empty:
             return results
-        above_threshold = mutual_info_df.loc[mutual_info_df['mutual_info'] >= self.threshold]
-        correlated_cols = [(col_1, col_2) for col_1, col_2 in zip(above_threshold['column_1'], above_threshold['column_2'])]
+        above_threshold = mutual_info_df.loc[
+            mutual_info_df["mutual_info"] >= self.threshold
+        ]
+        correlated_cols = [
+            (col_1, col_2)
+            for col_1, col_2 in zip(
+                above_threshold["column_1"], above_threshold["column_2"]
+            )
+        ]
         if correlated_cols:
             warning_msg = "Columns are likely to be correlated: {}"
-            results["warnings"].append(DataCheckWarning(message=warning_msg.format(correlated_cols),
-                                                        data_check_name=self.name,
-                                                        message_code=DataCheckMessageCode.IS_MULTICOLLINEAR,
-                                                        details={"columns": correlated_cols}).to_dict())
+            results["warnings"].append(
+                DataCheckWarning(
+                    message=warning_msg.format(correlated_cols),
+                    data_check_name=self.name,
+                    message_code=DataCheckMessageCode.IS_MULTICOLLINEAR,
+                    details={"columns": correlated_cols},
+                ).to_dict()
+            )
         return results
