@@ -4,7 +4,7 @@ from evalml.data_checks import (
     DataCheckActionCode,
     DataCheckError,
     DataCheckMessageCode,
-    DataCheckWarning
+    DataCheckWarning,
 )
 from evalml.utils import infer_feature_types
 from evalml.utils.logger import get_logger
@@ -39,18 +39,22 @@ class NoVarianceDataCheck(DataCheck):
         message = f"{column_name} has {int(count_unique)} unique value."
 
         if count_unique <= 1:
-            return DataCheckError(message=message.format(name=column_name),
-                                  data_check_name=self.name,
-                                  message_code=DataCheckMessageCode.NO_VARIANCE,
-                                  details={"column": column_name})
+            return DataCheckError(
+                message=message.format(name=column_name),
+                data_check_name=self.name,
+                message_code=DataCheckMessageCode.NO_VARIANCE,
+                details={"column": column_name},
+            )
 
         elif count_unique == 2 and not self._dropnan and any_nulls:
-            return DataCheckWarning(message=f"{column_name} has two unique values including nulls. "
-                                    "Consider encoding the nulls for "
-                                    "this column to be useful for machine learning.",
-                                    data_check_name=self.name,
-                                    message_code=DataCheckMessageCode.NO_VARIANCE_WITH_NULL,
-                                    details={"column": column_name})
+            return DataCheckWarning(
+                message=f"{column_name} has two unique values including nulls. "
+                "Consider encoding the nulls for "
+                "this column to be useful for machine learning.",
+                data_check_name=self.name,
+                message_code=DataCheckMessageCode.NO_VARIANCE_WITH_NULL,
+                details={"column": column_name},
+            )
 
     def validate(self, X, y):
         """Check if the target or any of the features have no variance (1 unique value).
@@ -62,11 +66,7 @@ class NoVarianceDataCheck(DataCheck):
         Returns:
             dict: dict of warnings/errors corresponding to features or target with no variance.
         """
-        results = {
-            "warnings": [],
-            "errors": [],
-            "actions": []
-        }
+        results = {"warnings": [], "errors": [], "actions": []}
 
         X = infer_feature_types(X)
         y = infer_feature_types(y)
@@ -74,16 +74,23 @@ class NoVarianceDataCheck(DataCheck):
         unique_counts = X.nunique(dropna=self._dropnan).to_dict()
         any_nulls = (X.isnull().any()).to_dict()
         for col_name in unique_counts:
-            message = self._check_for_errors(col_name, unique_counts[col_name], any_nulls[col_name])
+            message = self._check_for_errors(
+                col_name, unique_counts[col_name], any_nulls[col_name]
+            )
             if not message:
                 continue
             DataCheck._add_message(message, results)
-            results["actions"].append(DataCheckAction(DataCheckActionCode.DROP_COL,
-                                                      metadata={"column": col_name}).to_dict())
+            results["actions"].append(
+                DataCheckAction(
+                    DataCheckActionCode.DROP_COL, metadata={"column": col_name}
+                ).to_dict()
+            )
         y_name = getattr(y, "name")
         if not y_name:
             y_name = "Y"
-        target_message = self._check_for_errors(y_name, y.nunique(dropna=self._dropnan), y.isnull().any())
+        target_message = self._check_for_errors(
+            y_name, y.nunique(dropna=self._dropnan), y.isnull().any()
+        )
         if target_message:
             DataCheck._add_message(target_message, results)
         return results
