@@ -3,7 +3,7 @@ from evalml.data_checks import (
     DataCheckAction,
     DataCheckActionCode,
     DataCheckMessageCode,
-    DataCheckWarning
+    DataCheckWarning,
 )
 from evalml.problem_types import handle_problem_types, is_multiclass
 from evalml.utils.woodwork_utils import infer_feature_types
@@ -59,25 +59,35 @@ class SparsityDataCheck(DataCheck):
                                                        "actions": [{"code": "DROP_COL",\
                                                                  "metadata": {"column": "sparse"}}]}
         """
-        results = {
-            "warnings": [],
-            "errors": [],
-            "actions": []
-        }
+        results = {"warnings": [], "errors": [], "actions": []}
 
         X = infer_feature_types(X)
 
-        res = X.apply(SparsityDataCheck.sparsity_score, count_threshold=self.unique_count_threshold)
+        res = X.apply(
+            SparsityDataCheck.sparsity_score,
+            count_threshold=self.unique_count_threshold,
+        )
         too_sparse_cols = [col for col in res.index[res < self.threshold]]
-        results["warnings"].extend([DataCheckWarning(message=warning_too_unique.format(col_name,
-                                                                                       self.problem_type),
-                                                     data_check_name=self.name,
-                                                     message_code=DataCheckMessageCode.TOO_SPARSE,
-                                                     details={"column": col_name, "sparsity_score": res.loc[col_name]}).to_dict()
-                                    for col_name in too_sparse_cols])
-        results["actions"].extend([DataCheckAction(action_code=DataCheckActionCode.DROP_COL,
-                                                   metadata={"column": col_name}).to_dict()
-                                   for col_name in too_sparse_cols])
+        results["warnings"].extend(
+            [
+                DataCheckWarning(
+                    message=warning_too_unique.format(col_name, self.problem_type),
+                    data_check_name=self.name,
+                    message_code=DataCheckMessageCode.TOO_SPARSE,
+                    details={"column": col_name, "sparsity_score": res.loc[col_name]},
+                ).to_dict()
+                for col_name in too_sparse_cols
+            ]
+        )
+        results["actions"].extend(
+            [
+                DataCheckAction(
+                    action_code=DataCheckActionCode.DROP_COL,
+                    metadata={"column": col_name},
+                ).to_dict()
+                for col_name in too_sparse_cols
+            ]
+        )
         return results
 
     @staticmethod
