@@ -5,6 +5,7 @@ from .binary_classification_objective import BinaryClassificationObjective
 
 class LeadScoring(BinaryClassificationObjective):
     """Lead scoring."""
+
     name = "Lead Scoring"
     greater_is_better = True
     score_needs_proba = False
@@ -21,16 +22,17 @@ class LeadScoring(BinaryClassificationObjective):
         self.true_positives = true_positives
         self.false_positives = false_positives
 
-    def objective_function(self, y_true, y_predicted, X=None):
+    def objective_function(self, y_true, y_predicted, X=None, sample_weight=None):
         """Calculate the profit per lead.
 
-            Arguments:
-                y_predicted (pd.Series): Predicted labels
-                y_true (pd.Series): True labels
-                X (pd.DataFrame): Ignored.
+        Arguments:
+            y_predicted (pd.Series): Predicted labels
+            y_true (pd.Series): True labels
+            X (pd.DataFrame): Ignored.
+            sample_weight (pd.DataFrame): Ignored.
 
-            Returns:
-                float: Profit per lead
+        Returns:
+            float: Profit per lead
         """
         y_true = self._standardize_input_type(y_true)
         y_predicted = self._standardize_input_type(y_predicted)
@@ -42,5 +44,7 @@ class LeadScoring(BinaryClassificationObjective):
         profit += self.false_positives * false_positives
 
         profit_per_lead = profit / len(y_true)
+        # penalty if our estimator only predicts 1 output by making the score 0
+        same_class_penalty = (2 - len(set(y_predicted))) * abs(profit_per_lead)
 
-        return profit_per_lead
+        return profit_per_lead - same_class_penalty
