@@ -28,8 +28,7 @@ class ObjectiveBase(ABC):
     @classmethod
     @abstractmethod
     def score_needs_proba(cls):
-        """Returns a boolean determining if the score() method needs probability estimates. This should be true for objectives which work with predicted probabilities, like log loss or AUC, and false for objectives which compare predicted class labels to the actual labels, like F1 or correlation.
-        """
+        """Returns a boolean determining if the score() method needs probability estimates. This should be true for objectives which work with predicted probabilities, like log loss or AUC, and false for objectives which compare predicted class labels to the actual labels, like F1 or correlation."""
 
     @property
     @classmethod
@@ -45,12 +44,13 @@ class ObjectiveBase(ABC):
 
     @classmethod
     @abstractmethod
-    def objective_function(cls, y_true, y_predicted, X=None):
+    def objective_function(cls, y_true, y_predicted, X=None, sample_weight=None):
         """Computes the relative value of the provided predictions compared to the actual labels, according a specified metric
          Arguments:
             y_predicted (pd.Series): Predicted values of length [n_samples]
             y_true (pd.Series): Actual class labels of length [n_samples]
             X (pd.DataFrame or np.ndarray): Extra data of shape [n_samples, n_features] necessary to calculate score
+            sample_weight (pd.DataFrame or np.ndarray): Sample weights used in computing objective value result
 
         Returns:
             Numerical value used to calculate score
@@ -61,13 +61,14 @@ class ObjectiveBase(ABC):
         """If True, this objective is only valid for positive data. Default False."""
         return False
 
-    def score(self, y_true, y_predicted, X=None):
+    def score(self, y_true, y_predicted, X=None, sample_weight=None):
         """Returns a numerical score indicating performance based on the differences between the predicted and actual values.
 
         Arguments:
             y_predicted (pd.Series): Predicted values of length [n_samples]
             y_true (pd.Series): Actual class labels of length [n_samples]
             X (pd.DataFrame or np.ndarray): Extra data of shape [n_samples, n_features] necessary to calculate score
+            sample_weight (pd.DataFrame or np.ndarray): Sample weights used in computing objective value result
 
         Returns:
             score
@@ -77,7 +78,9 @@ class ObjectiveBase(ABC):
         y_true = self._standardize_input_type(y_true)
         y_predicted = self._standardize_input_type(y_predicted)
         self.validate_inputs(y_true, y_predicted)
-        return self.objective_function(y_true, y_predicted, X=X)
+        return self.objective_function(
+            y_true, y_predicted, X=X, sample_weight=sample_weight
+        )
 
     @staticmethod
     def _standardize_input_type(input_data):
@@ -111,7 +114,11 @@ class ObjectiveBase(ABC):
             None
         """
         if y_predicted.shape[0] != y_true.shape[0]:
-            raise ValueError("Inputs have mismatched dimensions: y_predicted has shape {}, y_true has shape {}".format(len(y_predicted), len(y_true)))
+            raise ValueError(
+                "Inputs have mismatched dimensions: y_predicted has shape {}, y_true has shape {}".format(
+                    len(y_predicted), len(y_true)
+                )
+            )
         if len(y_true) == 0:
             raise ValueError("Length of inputs is 0")
         if np.isnan(y_true).any() or np.isinf(y_true).any():
@@ -121,7 +128,9 @@ class ObjectiveBase(ABC):
         if np.isnan(y_pred_flat).any() or np.isinf(y_pred_flat).any():
             raise ValueError("y_predicted contains NaN or infinity")
         if self.score_needs_proba and np.any([(y_pred_flat < 0) | (y_pred_flat > 1)]):
-            raise ValueError("y_predicted contains probability estimates not within [0, 1]")
+            raise ValueError(
+                "y_predicted contains probability estimates not within [0, 1]"
+            )
 
     @classmethod
     def calculate_percent_difference(cls, score, baseline_score):
@@ -145,15 +154,24 @@ class ObjectiveBase(ABC):
             return 0
 
         # Return inf when dividing by 0
-        if np.isclose(baseline_score, 0, atol=1e-10) and not cls.is_bounded_like_percentage:
+        if (
+            np.isclose(baseline_score, 0, atol=1e-10)
+            and not cls.is_bounded_like_percentage
+        ):
             return np.inf
 
         decrease = False
-        if (baseline_score > score and cls.greater_is_better) or (baseline_score < score and not cls.greater_is_better):
+        if (baseline_score > score and cls.greater_is_better) or (
+            baseline_score < score and not cls.greater_is_better
+        ):
             decrease = True
 
-        difference = (baseline_score - score)
-        change = difference if cls.is_bounded_like_percentage else difference / baseline_score
+        difference = baseline_score - score
+        change = (
+            difference
+            if cls.is_bounded_like_percentage
+            else difference / baseline_score
+        )
         return 100 * (-1) ** (decrease) * np.abs(change)
 
     @classmethod
