@@ -1,4 +1,3 @@
-
 import pandas as pd
 from sklearn.preprocessing import LabelEncoder
 
@@ -9,13 +8,20 @@ from evalml.utils import infer_feature_types
 class ClassificationPipeline(PipelineBase):
     """Pipeline subclass for all classification pipelines."""
 
-    def __init__(self, component_graph, parameters=None, custom_name=None, custom_hyperparameters=None, random_seed=0):
+    def __init__(
+        self,
+        component_graph,
+        parameters=None,
+        custom_name=None,
+        random_seed=0,
+    ):
         self._encoder = LabelEncoder()
-        super().__init__(component_graph,
-                         custom_name=custom_name,
-                         parameters=parameters,
-                         custom_hyperparameters=custom_hyperparameters,
-                         random_seed=random_seed)
+        super().__init__(
+            component_graph,
+            custom_name=custom_name,
+            parameters=parameters,
+            random_seed=random_seed,
+        )
 
     def fit(self, X, y):
         """Build a classification model. For string and categorical targets, classes are sorted
@@ -45,16 +51,18 @@ class ClassificationPipeline(PipelineBase):
 
     def _decode_targets(self, y):
         """Converts encoded numerical values to their original target values.
-            Note: we cast y as ints first to address boolean values that may be returned from
-            calculating predictions which we would not be able to otherwise transform if we
-            originally had integer targets."""
+        Note: we cast y as ints first to address boolean values that may be returned from
+        calculating predictions which we would not be able to otherwise transform if we
+        originally had integer targets."""
         return self._encoder.inverse_transform(y.astype(int))
 
     @property
     def classes_(self):
         """Gets the class names for the problem."""
         if not hasattr(self._encoder, "classes_"):
-            raise AttributeError("Cannot access class names before fitting the pipeline.")
+            raise AttributeError(
+                "Cannot access class names before fitting the pipeline."
+            )
         return self._encoder.classes_
 
     def _predict(self, X, objective=None):
@@ -67,7 +75,7 @@ class ClassificationPipeline(PipelineBase):
         Returns:
             pd.Series: Estimated labels
         """
-        return self._component_graph.predict(X)
+        return self.component_graph.predict(X)
 
     def predict(self, X, objective=None):
         """Make predictions using selected features.
@@ -80,7 +88,9 @@ class ClassificationPipeline(PipelineBase):
             pd.Series: Estimated labels
         """
         predictions = self._predict(X, objective=objective)
-        predictions = pd.Series(self._decode_targets(predictions), name=self.input_target_name)
+        predictions = pd.Series(
+            self._decode_targets(predictions), name=self.input_target_name
+        )
         return infer_feature_types(predictions)
 
     def predict_proba(self, X):
@@ -94,7 +104,12 @@ class ClassificationPipeline(PipelineBase):
         """
         X = self.compute_estimator_features(X, y=None)
         proba = self.estimator.predict_proba(X)
-        proba = proba.ww.rename(columns={col: new_col for col, new_col in zip(proba.columns, self._encoder.classes_)})
+        proba = proba.ww.rename(
+            columns={
+                col: new_col
+                for col, new_col in zip(proba.columns, self._encoder.classes_)
+            }
+        )
         return infer_feature_types(proba)
 
     def score(self, X, y, objectives):
@@ -112,14 +127,20 @@ class ClassificationPipeline(PipelineBase):
         objectives = self.create_objectives(objectives)
         y = self._encode_targets(y)
         y_predicted, y_predicted_proba = self._compute_predictions(X, y, objectives)
-        return self._score_all_objectives(X, y, y_predicted, y_predicted_proba, objectives)
+        return self._score_all_objectives(
+            X, y, y_predicted, y_predicted_proba, objectives
+        )
 
     def _compute_predictions(self, X, y, objectives, time_series=False):
         """Compute predictions/probabilities based on objectives."""
         y_predicted = None
         y_predicted_proba = None
         if any(o.score_needs_proba for o in objectives):
-            y_predicted_proba = self.predict_proba(X, y) if time_series else self.predict_proba(X)
+            y_predicted_proba = (
+                self.predict_proba(X, y) if time_series else self.predict_proba(X)
+            )
         if any(not o.score_needs_proba for o in objectives):
-            y_predicted = self._predict(X, y, pad=True) if time_series else self._predict(X)
+            y_predicted = (
+                self._predict(X, y, pad=True) if time_series else self._predict(X)
+            )
         return y_predicted, y_predicted_proba
