@@ -9,16 +9,27 @@ from evalml.problem_types import ProblemTypes
 
 class StackedEnsembleRegressor(StackedEnsembleBase):
     """Stacked Ensemble Regressor."""
+
     name = "Stacked Ensemble Regressor"
     model_family = ModelFamily.ENSEMBLE
-    supported_problem_types = [ProblemTypes.REGRESSION, ProblemTypes.TIME_SERIES_REGRESSION]
+    supported_problem_types = [
+        ProblemTypes.REGRESSION,
+        ProblemTypes.TIME_SERIES_REGRESSION,
+    ]
     hyperparameter_ranges = {}
     _stacking_estimator_class = StackingRegressor
     _default_final_estimator = LinearRegressor
     _default_cv = KFold
 
-    def __init__(self, input_pipelines=None, final_estimator=None,
-                 cv=None, n_jobs=-1, random_seed=0, **kwargs):
+    def __init__(
+        self,
+        input_pipelines=None,
+        final_estimator=None,
+        cv=None,
+        n_jobs=-1,
+        random_seed=0,
+        **kwargs
+    ):
         """Stacked ensemble regressor.
 
         Arguments:
@@ -39,5 +50,11 @@ class StackedEnsembleRegressor(StackedEnsembleBase):
                 - Note: there could be some multi-process errors thrown for values of `n_jobs != 1`. If this is the case, please use `n_jobs = 1`.
             random_seed (int): Seed for the random number generator. Defaults to 0.
         """
-        super().__init__(input_pipelines=input_pipelines, final_estimator=final_estimator, cv=cv,
-                         n_jobs=n_jobs, random_seed=random_seed, **kwargs)
+        super().__init__(
+            input_pipelines=input_pipelines,
+            final_estimator=final_estimator,
+            cv=cv,
+            n_jobs=n_jobs,
+            random_seed=random_seed,
+            **kwargs
+        )
