@@ -6,29 +6,36 @@ from evalml.pipelines.components import ComponentBaseMeta
 from evalml.pipelines.components.transformers.transformer import Transformer
 from evalml.utils import (
     _retain_custom_types_and_initalize_woodwork,
-    infer_feature_types
+    infer_feature_types,
 )
 
 
 class OneHotEncoderMeta(ComponentBaseMeta):
     """A version of the ComponentBaseMeta class which includes validation on an additional one-hot-encoder-specific method `categories`"""
-    METHODS_TO_CHECK = ComponentBaseMeta.METHODS_TO_CHECK + ['categories', 'get_feature_names']
+
+    METHODS_TO_CHECK = ComponentBaseMeta.METHODS_TO_CHECK + [
+        "categories",
+        "get_feature_names",
+    ]
 
 
 class OneHotEncoder(Transformer, metaclass=OneHotEncoderMeta):
     """One-hot encoder to encode non-numeric data."""
-    name = 'One Hot Encoder'
+
+    name = "One Hot Encoder"
     hyperparameter_ranges = {}
 
-    def __init__(self,
-                 top_n=10,
-                 features_to_encode=None,
-                 categories=None,
-                 drop='if_binary',
-                 handle_unknown="ignore",
-                 handle_missing="error",
-                 random_seed=0,
-                 **kwargs):
+    def __init__(
+        self,
+        top_n=10,
+        features_to_encode=None,
+        categories=None,
+        drop="if_binary",
+        handle_unknown="ignore",
+        handle_missing="error",
+        random_seed=0,
+        **kwargs,
+    ):
         """Initalizes an transformer that encodes categorical features in a one-hot numeric array."
 
         Arguments:
@@ -49,79 +56,103 @@ class OneHotEncoder(Transformer, metaclass=OneHotEncoderMeta):
                 values encountered will raise an error. Defaults to "error".
             random_seed (int): Seed for the random number generator. Defaults to 0.
         """
-        parameters = {"top_n": top_n,
-                      "features_to_encode": features_to_encode,
-                      "categories": categories,
-                      "drop": drop,
-                      "handle_unknown": handle_unknown,
-                      "handle_missing": handle_missing}
+        parameters = {
+            "top_n": top_n,
+            "features_to_encode": features_to_encode,
+            "categories": categories,
+            "drop": drop,
+            "handle_unknown": handle_unknown,
+            "handle_missing": handle_missing,
+        }
         parameters.update(kwargs)
 
         # Check correct inputs
         unknown_input_options = ["ignore", "error"]
         missing_input_options = ["as_category", "error"]
         if handle_unknown not in unknown_input_options:
-            raise ValueError("Invalid input {} for handle_unknown".format(handle_unknown))
+            raise ValueError(
+                "Invalid input {} for handle_unknown".format(handle_unknown)
+            )
         if handle_missing not in missing_input_options:
-            raise ValueError("Invalid input {} for handle_missing".format(handle_missing))
+            raise ValueError(
+                "Invalid input {} for handle_missing".format(handle_missing)
+            )
         if top_n is not None and categories is not None:
             raise ValueError("Cannot use categories and top_n arguments simultaneously")
 
         self.features_to_encode = features_to_encode
         self._encoder = None
-        super().__init__(parameters=parameters,
-                         component_obj=None,
-                         random_seed=random_seed)
+        super().__init__(
+            parameters=parameters, component_obj=None, random_seed=random_seed
+        )
         self._initial_state = self.random_seed
         self._provenance = {}
 
     @staticmethod
     def _get_cat_cols(X):
         """Get names of categorical columns in the input DataFrame."""
-        return list(X.ww.select(include=['category']).columns)
+        return list(X.ww.select(include=["category"]).columns)
 
     def fit(self, X, y=None):
-        top_n = self.parameters['top_n']
+        top_n = self.parameters["top_n"]
         X = infer_feature_types(X)
         if self.features_to_encode is None:
             self.features_to_encode = self._get_cat_cols(X)
 
         X_t = X
-        invalid_features = [col for col in self.features_to_encode if col not in list(X.columns)]
+        invalid_features = [
+            col for col in self.features_to_encode if col not in list(X.columns)
+        ]
         if len(invalid_features) > 0:
-            raise ValueError("Could not find and encode {} in input data.".format(', '.join(invalid_features)))
+            raise ValueError(
+                "Could not find and encode {} in input data.".format(
+                    ", ".join(invalid_features)
+                )
+            )
 
         X_t = self._handle_parameter_handle_missing(X_t)
         self._binary_values_to_drop = []
 
         if len(self.features_to_encode) == 0:
-            categories = 'auto'
-        elif self.parameters['categories'] is not None:
-            categories = self.parameters['categories']
-            if len(categories) != len(self.features_to_encode) or not isinstance(categories[0], list):
-                raise ValueError('Categories argument must contain a list of categories for each categorical feature')
+            categories = "auto"
+        elif self.parameters["categories"] is not None:
+            categories = self.parameters["categories"]
+            if len(categories) != len(self.features_to_encode) or not isinstance(
+                categories[0], list
+            ):
+                raise ValueError(
+                    "Categories argument must contain a list of categories for each categorical feature"
+                )
         else:
             categories = []
             for col in X_t[self.features_to_encode]:
                 value_counts = X_t[col].value_counts(dropna=False).to_frame()
-                if self.parameters['drop'] == "if_binary" and len(value_counts) == 2:
+                if self.parameters["drop"] == "if_binary" and len(value_counts) == 2:
                     majority_class_value = value_counts.index.tolist()[0]
                     self._binary_values_to_drop.append((col, majority_class_value))
                 if top_n is None or len(value_counts) <= top_n:
                     unique_values = value_counts.index.tolist()
                 else:
-                    value_counts = value_counts.sample(frac=1, random_state=self._initial_state)
-                    value_counts = value_counts.sort_values([col], ascending=False, kind='mergesort')
+                    value_counts = value_counts.sample(
+                        frac=1, random_state=self._initial_state
+                    )
+                    value_counts = value_counts.sort_values(
+                        [col], ascending=False, kind="mergesort"
+                    )
                     unique_values = value_counts.head(top_n).index.tolist()
                 unique_values = np.sort(unique_values)
                 categories.append(unique_values)
 
         # Create an encoder to pass off the rest of the computation to
         # if "drop" is set to "if_binary", pass None to scikit-learn because we manually handle
-        drop_to_use = None if self.parameters['drop'] == "if_binary" else self.parameters['drop']
-        self._encoder = SKOneHotEncoder(categories=categories,
-                                        drop=drop_to_use,
-                                        handle_unknown=self.parameters['handle_unknown'])
+        drop_to_use = (
+            None if self.parameters["drop"] == "if_binary" else self.parameters["drop"]
+        )
+        self._encoder = SKOneHotEncoder(
+            categories=categories,
+            drop=drop_to_use,
+            handle_unknown=self.parameters["handle_unknown"],
+        )
 
         self._encoder.fit(X_t[self.features_to_encode])
         return self
@@ -144,7 +175,10 @@ class OneHotEncoder(Transformer, metaclass=OneHotEncoderMeta):
 
         # Call sklearn's transform on the categorical columns
         if len(self.features_to_encode) > 0:
-            X_cat = pd.DataFrame(self._encoder.transform(X_copy[self.features_to_encode]).toarray(), index=X_copy.index)
+            X_cat = pd.DataFrame(
+                self._encoder.transform(X_copy[self.features_to_encode]).toarray(),
+                index=X_copy.index,
+            )
             X_cat.columns = self._get_feature_names()
             X_cat.drop(columns=self._features_to_drop, inplace=True)
             X_cat.ww.init(logical_types={c: "Boolean" for c in X_cat.columns})
@@ -157,13 +191,13 @@ class OneHotEncoder(Transformer, metaclass=OneHotEncoderMeta):
     def _handle_parameter_handle_missing(self, X):
         """Helper method to handle the `handle_missing` parameter."""
         cat_cols = self.features_to_encode
-        if self.parameters['handle_missing'] == "error" and X.isnull().any().any():
+        if self.parameters["handle_missing"] == "error" and X.isnull().any().any():
             raise ValueError("Input contains NaN")
-        if self.parameters['handle_missing'] == "as_category":
+        if self.parameters["handle_missing"] == "as_category":
             for col in cat_cols:
-                if X[col].dtype == 'category' and pd.isna(X[col]).any():
+                if X[col].dtype == "category" and pd.isna(X[col]).any():
                     X[col] = X[col].cat.add_categories("nan")
-                    X[col] = X[col].where(~pd.isna(X[col]), other='nan')
+                    X[col] = X[col].where(~pd.isna(X[col]), other="nan")
                 X[col] = X[col].replace(np.nan, "nan")
         return X
 
@@ -178,7 +212,9 @@ class OneHotEncoder(Transformer, metaclass=OneHotEncoderMeta):
         try:
             index = self.features_to_encode.index(feature_name)
         except Exception:
-            raise ValueError(f'Feature "{feature_name}" was not provided to one-hot encoder as a training feature')
+            raise ValueError(
+                f'Feature "{feature_name}" was not provided to one-hot encoder as a training feature'
+            )
         return self._encoder.categories_[index]
 
     @staticmethod
@@ -219,7 +255,10 @@ class OneHotEncoder(Transformer, metaclass=OneHotEncoderMeta):
             for cat_index, category in enumerate(column_categories):
 
                 # Drop categories specified by the user
-                if self._encoder.drop_idx_ is not None and self._encoder.drop_idx_[col_index] is not None:
+                if (
+                    self._encoder.drop_idx_ is not None
+                    and self._encoder.drop_idx_[col_index] is not None
+                ):
                     if cat_index == self._encoder.drop_idx_[col_index]:
                         continue
 
