@@ -1,12 +1,15 @@
 import pandas as pd
 from skopt.space import Integer
 
-from evalml.pipelines.components.transformers.transformer import Transformer
+from evalml.pipelines.components.transformers.transformer import (
+    TargetTransformer,
+)
 from evalml.utils import import_or_raise, infer_feature_types
 
 
-class PolynomialDetrender(Transformer):
+class PolynomialDetrender(TargetTransformer):
     """Removes trends from time series by fitting a polynomial to the data."""
+
     name = "Polynomial Detrender"
 
     hyperparameter_ranges = {"degree": Integer(1, 3)}
@@ -23,20 +26,24 @@ class PolynomialDetrender(Transformer):
             if isinstance(degree, float) and degree.is_integer():
                 degree = int(degree)
             else:
-                raise TypeError(f"Parameter Degree must be an integer!: Received {type(degree).__name__}")
+                raise TypeError(
+                    f"Parameter Degree must be an integer!: Received {type(degree).__name__}"
+                )
 
         params = {"degree": degree}
         params.update(kwargs)
         error_msg = "sktime is not installed. Please install using 'pip install sktime'"
 
         trend = import_or_raise("sktime.forecasting.trend", error_msg=error_msg)
-        detrend = import_or_raise("sktime.transformations.series.detrend", error_msg=error_msg)
+        detrend = import_or_raise(
+            "sktime.transformations.series.detrend", error_msg=error_msg
+        )
 
         detrender = detrend.Detrender(trend.PolynomialTrendForecaster(degree=degree))
 
-        super().__init__(parameters=params,
-                         component_obj=detrender,
-                         random_seed=random_seed)
+        super().__init__(
+            parameters=params, component_obj=detrender, random_seed=random_seed
+        )
 
     def fit(self, X, y=None):
         """Fits the PolynomialDetrender.
@@ -85,7 +92,7 @@ class PolynomialDetrender(Transformer):
         """
         return self.fit(X, y).transform(X, y)
 
-    def inverse_transform(self, X, y):
+    def inverse_transform(self, y):
         """Adds back fitted trend to target variable.
 
         Arguments:
@@ -101,4 +108,4 @@ class PolynomialDetrender(Transformer):
         y_dt = infer_feature_types(y)
         y_t = self._component_obj.inverse_transform(y_dt)
         y_t = infer_feature_types(pd.Series(y_t, index=y_dt.index))
-        return X, y_t
+        return y_t
