@@ -16,10 +16,10 @@ class TextTransformer(Transformer):
         parameters = {}
         parameters.update(kwargs)
 
-        super().__init__(parameters=parameters,
-                         component_obj=component_obj,
-                         random_seed=random_seed)
+        super().__init__(
+            parameters=parameters, component_obj=component_obj, random_seed=random_seed
+        )
 
     def _get_text_columns(self, X):
         """Returns the ordered list of columns names in the input which have been designated as text columns."""
-        return list(X.ww.select('NaturalLanguage').columns)
+        return list(X.ww.select("NaturalLanguage").columns)
