@@ -15,11 +15,12 @@ from .components import (
     Estimator,
     LinearDiscriminantAnalysis,
     StackedEnsembleClassifier,
-    StackedEnsembleRegressor
+    StackedEnsembleRegressor,
 )
 from .components.utils import all_components, handle_component_class
 
 from evalml.exceptions import ObjectiveCreationError, PipelineScoreError
+from evalml.exceptions.exceptions import MissingComponentError
 from evalml.objectives import get_objective
 from evalml.pipelines import ComponentGraph
 from evalml.pipelines.pipeline_meta import PipelineBaseMeta
@@ -31,7 +32,7 @@ from evalml.utils import (
     jupyter_check,
     log_subtitle,
     log_title,
-    safe_repr
+    safe_repr,
 )
 
 logger = get_logger(__file__)
@@ -42,12 +43,13 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
 
     problem_type = None
 
-    def __init__(self,
-                 component_graph,
-                 parameters=None,
-                 custom_name=None,
-                 custom_hyperparameters=None,
-                 random_seed=0):
+    def __init__(
+        self,
+        component_graph,
+        parameters=None,
+        custom_name=None,
+        random_seed=0,
+    ):
         """Machine learning pipeline made out of transformers and a estimator.
 
         Arguments:
@@ -59,27 +61,39 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             parameters (dict): Dictionary with component names as keys and dictionary of that component's parameters as values.
                  An empty dictionary or None implies using all default values for component parameters. Defaults to None.
             custom_name (str): Custom name for the pipeline. Defaults to None.
-            custom_hyperparameters (dict): Custom hyperparameter range for the pipeline. Defaults to None.
             random_seed (int): Seed for the random number generator. Defaults to 0.
         """
-        self._custom_hyperparameters = custom_hyperparameters
         self.random_seed = random_seed
 
-        self.component_graph = component_graph
         if isinstance(component_graph, list):  # Backwards compatibility
-            self._component_graph = ComponentGraph().from_list(component_graph, random_seed=self.random_seed)
-        else:
-            self._component_graph = ComponentGraph(component_dict=component_graph, random_seed=self.random_seed)
-        self._component_graph.instantiate(parameters)
+            self.component_graph = ComponentGraph().from_list(
+                component_graph, random_seed=self.random_seed
+            )
+        elif isinstance(component_graph, dict):
+            self.component_graph = ComponentGraph(
+                component_dict=component_graph, random_seed=self.random_seed
+            )
+        elif isinstance(component_graph, ComponentGraph):
+            self.component_graph = ComponentGraph(
+                component_dict=component_graph.component_dict,
+                random_seed=self.random_seed,
+            )
+        self.component_graph.instantiate(parameters)
 
         self.input_feature_names = {}
         self.input_target_name = None
 
         self.estimator = None
-        if len(self._component_graph.compute_order) > 0:
-            final_component = self._component_graph.get_last_component()
-            self.estimator = final_component if isinstance(final_component, Estimator) else None
-        self._estimator_name = self._component_graph.compute_order[-1] if self.estimator is not None else None
+        if len(self.component_graph.compute_order) > 0:
+            final_component = self.component_graph.get_last_component()
+            self.estimator = (
+                final_component if isinstance(final_component, Estimator) else None
+            )
+        self._estimator_name = (
+            self.component_graph.compute_order[-1]
+            if self.estimator is not None
+            else None
+        )
 
         self._validate_estimator_problem_type()
         self._is_fitted = False
@@ -90,16 +104,6 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
 
         self._custom_name = custom_name
 
-    @property
-    def custom_hyperparameters(self):
-        """Custom hyperparameters for the pipeline."""
-        return self._custom_hyperparameters
-
-    @custom_hyperparameters.setter
-    def custom_hyperparameters(self, value):
-        """Custom hyperparameters for the pipeline."""
-        self._custom_hyperparameters = value
-
     @property
     def custom_name(self):
         """Custom name of the pipeline."""
@@ -115,19 +119,24 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         """A short summary of the pipeline structure, describing the list of components used.
         Example: Logistic Regression Classifier w/ Simple Imputer + One Hot Encoder
         """
-        component_graph = [handle_component_class(component_class) for _, component_class in copy.copy(self.linearized_component_graph)]
+        component_graph = [
+            handle_component_class(component_class)
+            for _, component_class in copy.copy(self.linearized_component_graph)
+        ]
         if len(component_graph) == 0:
             return "Empty Pipeline"
         summary = "Pipeline"
         component_graph[-1] = component_graph[-1]
 
-        if inspect.isclass(component_graph[-1]) and issubclass(component_graph[-1], Estimator):
+        if inspect.isclass(component_graph[-1]) and issubclass(
+            component_graph[-1], Estimator
+        ):
             estimator_class = component_graph.pop(-1)
             summary = estimator_class.name
         if len(component_graph) == 0:
             return summary
         component_names = [component_class.name for component_class in component_graph]
-        return '{} w/ {}'.format(summary, ' + '.join(component_names))
+        return "{} w/ {}".format(summary, " + ".join(component_names))
 
     @property
     def linearized_component_graph(self):
@@ -136,20 +145,25 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
 
     def _validate_estimator_problem_type(self):
         """Validates this pipeline's problem_type against that of the estimator from `self.component_graph`"""
-        if self.estimator is None:  # Allow for pipelines that do not end with an estimator
+        if (
+            self.estimator is None
+        ):  # Allow for pipelines that do not end with an estimator
             return
         estimator_problem_types = self.estimator.supported_problem_types
         if self.problem_type not in estimator_problem_types:
-            raise ValueError("Problem type {} not valid for this component graph. Valid problem types include {}."
-                             .format(self.problem_type, estimator_problem_types))
+            raise ValueError(
+                "Problem type {} not valid for this component graph. Valid problem types include {}.".format(
+                    self.problem_type, estimator_problem_types
+                )
+            )
 
     def __getitem__(self, index):
         if isinstance(index, slice):
-            raise NotImplementedError('Slicing pipelines is currently not supported.')
-        return self._component_graph[index]
+            raise NotImplementedError("Slicing pipelines is currently not supported.")
+        return self.component_graph[index]
 
     def __setitem__(self, index, value):
-        raise NotImplementedError('Setting pipeline components is not supported.')
+        raise NotImplementedError("Setting pipeline components is not supported.")
 
     def get_component(self, name):
         """Returns component by name
@@ -161,7 +175,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             Component: Component to return
 
         """
-        return self._component_graph.get_component(name)
+        return self.component_graph.get_component(name)
 
     def describe(self, return_dict=False):
         """Outputs pipeline details including component parameters
@@ -177,7 +191,11 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         logger.info("Model Family: {}".format(str(self.model_family)))
 
         if self._estimator_name in self.input_feature_names:
-            logger.info("Number of features: {}".format(len(self.input_feature_names[self._estimator_name])))
+            logger.info(
+                "Number of features: {}".format(
+                    len(self.input_feature_names[self._estimator_name])
+                )
+            )
 
         # Summary of steps
         log_subtitle(logger, "Pipeline Steps")
@@ -186,14 +204,11 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             "name": self.name,
             "problem_type": self.problem_type,
             "model_family": self.model_family,
-            "components": dict()
+            "components": dict(),
         }
-
-        for number, component in enumerate(self._component_graph, 1):
-            component_string = str(number) + ". " + component.name
-            logger.info(component_string)
-            pipeline_dict["components"].update({component.name: component.describe(print_name=False, return_dict=return_dict)})
+        component_dict = self.component_graph.describe(return_dict=return_dict)
         if return_dict:
+            pipeline_dict.update({"components": component_dict})
             return pipeline_dict
 
     def compute_estimator_features(self, X, y=None):
@@ -205,19 +220,13 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Returns:
             pd.DataFrame: New transformed features.
         """
-        X_t = self._component_graph.compute_final_component_features(X, y=y)
-        return X_t
-
-    def _compute_features_during_fit(self, X, y):
-        self.input_target_name = y.name
-        X_t = self._component_graph.fit_features(X, y)
-        self.input_feature_names = self._component_graph.input_feature_names
+        X_t = self.component_graph.compute_final_component_features(X, y=y)
         return X_t
 
     def _fit(self, X, y):
         self.input_target_name = y.name
-        self._component_graph.fit(X, y)
-        self.input_feature_names = self._component_graph.input_feature_names
+        self.component_graph.fit(X, y)
+        self.input_feature_names = self.component_graph.input_feature_names
 
     @abstractmethod
     def fit(self, X, y):
@@ -243,7 +252,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             pd.Series: Predicted values.
         """
         X = infer_feature_types(X)
-        predictions = self._component_graph.predict(X)
+        predictions = self.component_graph.predict(X)
         predictions.name = self.input_target_name
         return infer_feature_types(predictions)
 
@@ -284,9 +293,18 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         for objective in objectives:
             try:
                 if not objective.is_defined_for_problem_type(self.problem_type):
-                    raise ValueError(f'Invalid objective {objective.name} specified for problem type {self.problem_type}')
-                y_pred = self._select_y_pred_for_score(X, y, y_pred, y_pred_proba, objective)
-                score = self._score(X, y, y_pred_proba if objective.score_needs_proba else y_pred, objective)
+                    raise ValueError(
+                        f"Invalid objective {objective.name} specified for problem type {self.problem_type}"
+                    )
+                y_pred = self._select_y_pred_for_score(
+                    X, y, y_pred, y_pred_proba, objective
+                )
+                score = self._score(
+                    X,
+                    y,
+                    y_pred_proba if objective.score_needs_proba else y_pred,
+                    objective,
+                )
                 scored_successfully.update({objective.name: score})
             except Exception as e:
                 tb = traceback.format_tb(sys.exc_info()[2])
@@ -303,24 +321,15 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
     @property
     def model_family(self):
         """Returns model family of this pipeline template"""
-        component_graph = copy.copy(self._component_graph)
+        component_graph = copy.copy(self.component_graph)
         if isinstance(component_graph, list):
             return handle_component_class(component_graph[-1]).model_family
         else:
             order = ComponentGraph.generate_order(component_graph.component_dict)
             final_component = order[-1]
-            return handle_component_class(component_graph[final_component].__class__).model_family
-
-    @property
-    def hyperparameters(self):
-        """Returns hyperparameter ranges from all components as a dictionary"""
-        hyperparameter_ranges = dict()
-        for component_name, component_class in self.linearized_component_graph:
-            component_hyperparameters = copy.copy(component_class.hyperparameter_ranges)
-            if self.custom_hyperparameters and component_name in self.custom_hyperparameters:
-                component_hyperparameters.update(self.custom_hyperparameters.get(component_name, {}))
-            hyperparameter_ranges[component_name] = component_hyperparameters
-        return hyperparameter_ranges
+            return handle_component_class(
+                component_graph[final_component].__class__
+            ).model_family
 
     @property
     def parameters(self):
@@ -329,26 +338,17 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Returns:
             dict: Dictionary of all component parameters
         """
-        components = [(component_name, component_class) for component_name, component_class in self._component_graph.component_instances.items()]
-        component_parameters = {c_name: copy.copy(c.parameters) for c_name, c in components if c.parameters}
+        components = [
+            (component_name, component_class)
+            for component_name, component_class in self.component_graph.component_instances.items()
+        ]
+        component_parameters = {
+            c_name: copy.copy(c.parameters) for c_name, c in components if c.parameters
+        }
         if self._pipeline_params:
-            component_parameters['pipeline'] = self._pipeline_params
+            component_parameters["pipeline"] = self._pipeline_params
         return component_parameters
 
-    @property
-    def default_parameters(self):
-        """The default parameter dictionary for this pipeline.
-
-        Returns:
-            dict: Dictionary of all component default parameters.
-        """
-        defaults = {}
-        for c in self.component_graph:
-            component = handle_component_class(c)
-            if component.default_parameters:
-                defaults[component.name] = component.default_parameters
-        return defaults
-
     @property
     def feature_importance(self):
         """Importance associated with each feature. Features dropped by the feature selection are excluded.
@@ -357,7 +357,9 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             pd.DataFrame including feature names and their corresponding importance
         """
         feature_names = self.input_feature_names[self._estimator_name]
-        importance = list(zip(feature_names, self.estimator.feature_importance))  # note: this only works for binary
+        importance = list(
+            zip(feature_names, self.estimator.feature_importance)
+        )  # note: this only works for binary
         importance.sort(key=lambda x: -abs(x[1]))
         df = pd.DataFrame(importance, columns=["feature", "importance"])
         return df
@@ -371,18 +373,20 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Returns:
             graphviz.Digraph: Graph object that can be directly displayed in Jupyter notebooks.
         """
-        graphviz = import_or_raise('graphviz', error_msg='Please install graphviz to visualize pipelines.')
+        graphviz = import_or_raise(
+            "graphviz", error_msg="Please install graphviz to visualize pipelines."
+        )
 
         # Try rendering a dummy graph to see if a working backend is installed
         try:
             graphviz.Digraph().pipe()
         except graphviz.backend.ExecutableNotFound:
             raise RuntimeError(
-                "To graph pipelines, a graphviz backend is required.\n" +
-                "Install the backend using one of the following commands:\n" +
-                "  Mac OS: brew install graphviz\n" +
-                "  Linux (Ubuntu): sudo apt-get install graphviz\n" +
-                "  Windows: conda install python-graphviz\n"
+                "To graph pipelines, a graphviz backend is required.\n"
+                + "Install the backend using one of the following commands:\n"
+                + "  Mac OS: brew install graphviz\n"
+                + "  Linux (Ubuntu): sudo apt-get install graphviz\n"
+                + "  Windows: conda install python-graphviz\n"
             )
 
         graph_format = None
@@ -391,18 +395,24 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             # Explicitly cast to str in case a Path object was passed in
             filepath = str(filepath)
             try:
-                f = open(filepath, 'w')
+                f = open(filepath, "w")
                 f.close()
             except (IOError, FileNotFoundError):
-                raise ValueError(('Specified filepath is not writeable: {}'.format(filepath)))
+                raise ValueError(
+                    ("Specified filepath is not writeable: {}".format(filepath))
+                )
             path_and_name, graph_format = os.path.splitext(filepath)
             graph_format = graph_format[1:].lower()  # ignore the dot
             supported_filetypes = graphviz.backend.FORMATS
             if graph_format not in supported_filetypes:
-                raise ValueError(("Unknown format '{}'. Make sure your format is one of the " +
-                                  "following: {}").format(graph_format, supported_filetypes))
+                raise ValueError(
+                    (
+                        "Unknown format '{}'. Make sure your format is one of the "
+                        + "following: {}"
+                    ).format(graph_format, supported_filetypes)
+                )
 
-        graph = self._component_graph.graph(path_and_name, graph_format)
+        graph = self.component_graph.graph(path_and_name, graph_format)
 
         if filepath:
             graph.render(path_and_name, cleanup=True)
@@ -418,38 +428,39 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Returns:
             plotly.Figure, a bar graph showing features and their corresponding importance
         """
-        go = import_or_raise("plotly.graph_objects", error_msg="Cannot find dependency plotly.graph_objects")
+        go = import_or_raise(
+            "plotly.graph_objects",
+            error_msg="Cannot find dependency plotly.graph_objects",
+        )
         if jupyter_check():
             import_or_raise("ipywidgets", warning=True)
 
         feat_imp = self.feature_importance
-        feat_imp['importance'] = abs(feat_imp['importance'])
+        feat_imp["importance"] = abs(feat_imp["importance"])
 
         if importance_threshold < 0:
-            raise ValueError(f'Provided importance threshold of {importance_threshold} must be greater than or equal to 0')
+            raise ValueError(
+                f"Provided importance threshold of {importance_threshold} must be greater than or equal to 0"
+            )
 
         # Remove features with importance whose absolute value is less than importance threshold
-        feat_imp = feat_imp[feat_imp['importance'] >= importance_threshold]
+        feat_imp = feat_imp[feat_imp["importance"] >= importance_threshold]
 
         # List is reversed to go from ascending order to descending order
         feat_imp = feat_imp.iloc[::-1]
 
-        title = 'Feature Importance'
-        subtitle = 'May display fewer features due to feature selection'
-        data = [go.Bar(
-            x=feat_imp['importance'],
-            y=feat_imp['feature'],
-            orientation='h'
-        )]
+        title = "Feature Importance"
+        subtitle = "May display fewer features due to feature selection"
+        data = [
+            go.Bar(x=feat_imp["importance"], y=feat_imp["feature"], orientation="h")
+        ]
 
         layout = {
-            'title': '{0}<br><sub>{1}</sub>'.format(title, subtitle),
-            'height': 800,
-            'xaxis_title': 'Feature Importance',
-            'yaxis_title': 'Feature',
-            'yaxis': {
-                'type': 'category'
-            }
+            "title": "{0}<br><sub>{1}</sub>".format(title, subtitle),
+            "height": 800,
+            "xaxis_title": "Feature Importance",
+            "yaxis_title": "Feature",
+            "yaxis": {"type": "category"},
         }
 
         fig = go.Figure(data=data, layout=layout)
@@ -465,7 +476,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Returns:
             None
         """
-        with open(file_path, 'wb') as f:
+        with open(file_path, "wb") as f:
             cloudpickle.dump(self, f, protocol=pickle_protocol)
 
     @staticmethod
@@ -478,7 +489,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Returns:
             PipelineBase object
         """
-        with open(file_path, 'rb') as f:
+        with open(file_path, "rb") as f:
             return cloudpickle.load(f)
 
     def clone(self):
@@ -487,7 +498,12 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Returns:
             A new instance of this pipeline with identical components, parameters, and random state.
         """
-        return self.__class__(self.component_graph, parameters=self.parameters, custom_name=self.custom_name, custom_hyperparameters=self.custom_hyperparameters, random_seed=self.random_seed)
+        return self.__class__(
+            self.component_graph,
+            parameters=self.parameters,
+            custom_name=self.custom_name,
+            random_seed=self.random_seed,
+        )
 
     def new(self, parameters, random_seed=0):
         """Constructs a new instance of the pipeline with the same component graph but with a different set of parameters.
@@ -500,7 +516,12 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Returns:
             A new instance of this pipeline with identical components.
         """
-        return self.__class__(self.component_graph, parameters=parameters, custom_name=self.custom_name, custom_hyperparameters=self.custom_hyperparameters, random_seed=random_seed)
+        return self.__class__(
+            self.component_graph,
+            parameters=parameters,
+            custom_name=self.custom_name,
+            random_seed=random_seed,
+        )
 
     def __eq__(self, other):
         if not isinstance(other, self.__class__):
@@ -508,7 +529,13 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         random_seed_eq = self.random_seed == other.random_seed
         if not random_seed_eq:
             return False
-        attributes_to_check = ['parameters', '_is_fitted', 'component_graph', 'input_feature_names', 'input_target_name']
+        attributes_to_check = [
+            "parameters",
+            "_is_fitted",
+            "component_graph",
+            "input_feature_names",
+            "input_target_name",
+        ]
         for attribute in attributes_to_check:
             if getattr(self, attribute) != getattr(other, attribute):
                 return False
@@ -519,48 +546,108 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
 
     def __repr__(self):
         def repr_component(parameters):
-            return ', '.join([f"'{key}': {safe_repr(value)}" for key, value in parameters.items()])
+            return ", ".join(
+                [f"'{key}': {safe_repr(value)}" for key, value in parameters.items()]
+            )
 
-        component_graph_repr = ", ".join([f"'{component}'" if isinstance(component, str) else component.__name__ for component in self.component_graph])
-        component_graph_str = f"[{component_graph_repr}]"
+        component_strs = []
+        for (
+            component_name,
+            component_info,
+        ) in self.component_graph.component_dict.items():
+            try:
+                component_key = f"'{component_name}': "
+                if isinstance(component_info[0], str):
+                    component_class = handle_component_class(component_info[0])
+                else:
+                    component_class = handle_component_class(component_info[0].name)
+                component_name = f"'{component_class.name}'"
+            except MissingComponentError:
+                # Not an EvalML component, use component class name
+                component_name = f"{component_info[0].__name__}"
 
-        custom_hyperparameters_repr = ', '.join([f"'{component}':{{{repr_component(hyperparameters)}}}" for component, hyperparameters in self.custom_hyperparameters.items()]) if self.custom_hyperparameters else None
-        custom_hyperparmeter_str = f"custom_hyperparameters={{{custom_hyperparameters_repr}}}" if custom_hyperparameters_repr else None
+            component_edges_str = ""
+            if len(component_info) > 1:
+                component_edges_str = ", "
+                component_edges_str += ", ".join(
+                    [f"'{info}'" for info in component_info[1:]]
+                )
 
-        parameters_repr = ', '.join([f"'{component}':{{{repr_component(parameters)}}}" for component, parameters in self.parameters.items()])
+            component_str = f"{component_key}[{component_name}{component_edges_str}]"
+            component_strs.append(component_str)
+        component_dict_str = f"{{{', '.join(component_strs)}}}"
+
+        parameters_repr = ", ".join(
+            [
+                f"'{component}':{{{repr_component(parameters)}}}"
+                for component, parameters in self.parameters.items()
+            ]
+        )
         parameters_str = f"parameters={{{parameters_repr}}}"
 
-        custom_name_repr = f"custom_name='{self.custom_name}'" if self.custom_name else None
+        custom_name_repr = (
+            f"custom_name='{self.custom_name}'" if self.custom_name else None
+        )
         random_seed_str = f"random_seed={self.random_seed}"
-        additional_args_str = ", ".join([arg for arg in [parameters_str, custom_hyperparmeter_str, custom_name_repr, random_seed_str] if arg is not None])
+        additional_args_str = ", ".join(
+            [
+                arg
+                for arg in [
+                    parameters_str,
+                    custom_name_repr,
+                    random_seed_str,
+                ]
+                if arg is not None
+            ]
+        )
 
-        return f'pipeline = {(type(self).__name__)}(component_graph={component_graph_str}, {additional_args_str})'
+        return f"pipeline = {(type(self).__name__)}(component_graph={component_dict_str}, {additional_args_str})"
 
     def __iter__(self):
         return self
 
     def __next__(self):
-        return next(self._component_graph)
+        return next(self.component_graph)
 
     def _get_feature_provenance(self):
-        return self._component_graph._feature_provenance
+        return self.component_graph._feature_provenance
 
     @property
     def _supports_fast_permutation_importance(self):
-        has_more_than_one_estimator = sum(isinstance(c, Estimator) for c in self._component_graph) > 1
+        has_more_than_one_estimator = (
+            sum(isinstance(c, Estimator) for c in self.component_graph) > 1
+        )
         _all_components = set(all_components())
-        has_custom_components = any(c.__class__ not in _all_components for c in self._component_graph)
-        has_dim_reduction = any(isinstance(c, (PCA, LinearDiscriminantAnalysis)) for c in self._component_graph)
-        has_dfs = any(isinstance(c, DFSTransformer) for c in self._component_graph)
-        has_stacked_ensembler = any(isinstance(c, (StackedEnsembleClassifier, StackedEnsembleRegressor)) for c in self._component_graph)
-        return not any([has_more_than_one_estimator, has_custom_components, has_dim_reduction, has_dfs, has_stacked_ensembler])
+        has_custom_components = any(
+            c.__class__ not in _all_components for c in self.component_graph
+        )
+        has_dim_reduction = any(
+            isinstance(c, (PCA, LinearDiscriminantAnalysis))
+            for c in self.component_graph
+        )
+        has_dfs = any(isinstance(c, DFSTransformer) for c in self.component_graph)
+        has_stacked_ensembler = any(
+            isinstance(c, (StackedEnsembleClassifier, StackedEnsembleRegressor))
+            for c in self.component_graph
+        )
+        return not any(
+            [
+                has_more_than_one_estimator,
+                has_custom_components,
+                has_dim_reduction,
+                has_dfs,
+                has_stacked_ensembler,
+            ]
+        )
 
     @staticmethod
     def create_objectives(objectives):
         objective_instances = []
         for objective in objectives:
             try:
-                objective_instances.append(get_objective(objective, return_instance=True))
+                objective_instances.append(
+                    get_objective(objective, return_instance=True)
+                )
             except ObjectiveCreationError as e:
                 msg = f"Cannot pass {objective} as a string in pipeline.score. Instantiate first and then add it to the list of objectives."
                 raise ObjectiveCreationError(msg) from e
@@ -569,12 +656,26 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
     def can_tune_threshold_with_objective(self, objective):
         """Determine whether the threshold of a binary classification pipeline can be tuned.
 
-       Arguments:
-            pipeline (PipelineBase): Binary classification pipeline.
-            objective (ObjectiveBase): Primary AutoMLSearch objective.
+        Arguments:
+             pipeline (PipelineBase): Binary classification pipeline.
+             objective (ObjectiveBase): Primary AutoMLSearch objective.
 
-        Returns:
-            bool: True if the pipeline threshold can be tuned.
+         Returns:
+             bool: True if the pipeline threshold can be tuned.
 
         """
-        return is_binary(self.problem_type) and objective.is_defined_for_problem_type(self.problem_type) and objective.can_optimize_threshold
+        return (
+            is_binary(self.problem_type)
+            and objective.is_defined_for_problem_type(self.problem_type)
+            and objective.can_optimize_threshold
+        )
+
+    def inverse_transform(self, y):
+        """Apply component inverse_transform methods to estimator predictions in reverse order.
+
+        Components that implement inverse_transform are PolynomialDetrender, LabelEncoder (tbd).
+
+        Arguments:
+            y (pd.Series): Final component features
+        """
+        return self.component_graph.inverse_transform(y)
