@@ -1,4 +1,3 @@
-
 from evalml.pipelines import PipelineBase
 from evalml.problem_types import ProblemTypes
 from evalml.utils import infer_feature_types
@@ -6,6 +5,7 @@ from evalml.utils import infer_feature_types
 
 class RegressionPipeline(PipelineBase):
     """Pipeline subclass for all regression pipelines."""
+
     problem_type = ProblemTypes.REGRESSION
 
     def fit(self, X, y):
@@ -39,4 +39,6 @@ class RegressionPipeline(PipelineBase):
         """
         objectives = self.create_objectives(objectives)
         y_predicted = self.predict(X)
-        return self._score_all_objectives(X, y, y_predicted, y_pred_proba=None, objectives=objectives)
+        return self._score_all_objectives(
+            X, y, y_predicted, y_pred_proba=None, objectives=objectives
+        )
