@@ -23,7 +23,7 @@ class TimeSeriesSplit(BaseCrossValidator):
                 since we are interested in
             date_index (str): Name of the column containing the datetime information used to order the data.
             n_splits (int): number of data splits to make.
-            """
+        """
         self.max_delay = max_delay
         self.gap = gap
         self.date_index = date_index
@@ -57,7 +57,9 @@ class TimeSeriesSplit(BaseCrossValidator):
         # TimeSeriesPipeline convention of being able to pass in empty X dataframes
         # We'll do this by passing X=y if X is empty
         if self._check_if_empty(X) and self._check_if_empty(y):
-            raise ValueError("Both X and y cannot be None or empty in TimeSeriesSplit.split")
+            raise ValueError(
+                "Both X and y cannot be None or empty in TimeSeriesSplit.split"
+            )
         elif self._check_if_empty(X) and not self._check_if_empty(y):
             split_kwargs = dict(X=y, groups=groups)
             max_index = y.shape[0]
@@ -65,13 +67,15 @@ class TimeSeriesSplit(BaseCrossValidator):
             split_kwargs = dict(X=X, y=y, groups=groups)
             max_index = X.shape[0]
 
-        split_size = (max_index // self.n_splits)
+        split_size = max_index // self.n_splits
         if split_size < self.gap + self.max_delay:
-            raise ValueError(f"Since the data has {max_index} observations and n_splits={self.n_splits}, "
-                             f"the smallest split would have {split_size} observations. "
-                             f"Since {self.gap + self.max_delay} (gap + max_delay)  > {split_size}, "
-                             "then at least one of the splits would be empty by the time it reaches the pipeline. "
-                             "Please use a smaller number of splits or collect more data.")
+            raise ValueError(
+                f"Since the data has {max_index} observations and n_splits={self.n_splits}, "
+                f"the smallest split would have {split_size} observations. "
+                f"Since {self.gap + self.max_delay} (gap + max_delay)  > {split_size}, "
+                "then at least one of the splits would be empty by the time it reaches the pipeline. "
+                "Please use a smaller number of splits or collect more data."
+            )
 
         for train, test in self._splitter.split(**split_kwargs):
             last_train = train[-1]
