@@ -7,13 +7,15 @@ from evalml.problem_types import (
     is_binary,
     is_multiclass,
     is_regression,
-    is_time_series
+    is_time_series,
 )
 
 
 @pytest.mark.parametrize("problem_type", ProblemTypes.all_problem_types)
-@pytest.mark.parametrize("data_type", ['np', 'pd', 'ww'])
-def test_split_data(problem_type, data_type, X_y_binary, X_y_multi, X_y_regression, make_data_type):
+@pytest.mark.parametrize("data_type", ["np", "pd", "ww"])
+def test_split_data(
+    problem_type, data_type, X_y_binary, X_y_multi, X_y_regression, make_data_type
+):
     if is_binary(problem_type):
         X, y = X_y_binary
     if is_multiclass(problem_type):
@@ -22,14 +24,19 @@ def test_split_data(problem_type, data_type, X_y_binary, X_y_multi, X_y_regressi
         X, y = X_y_regression
     problem_configuration = None
     if is_time_series(problem_type):
-        problem_configuration = {'gap': 1, 'max_delay': 7, "date_index": None}
+        problem_configuration = {"gap": 1, "max_delay": 7, "date_index": None}
 
     X = make_data_type(data_type, X)
     y = make_data_type(data_type, y)
 
     test_pct = 0.25
-    X_train, X_test, y_train, y_test = split_data(X, y, test_size=test_pct, problem_type=problem_type,
-                                                  problem_configuration=problem_configuration)
+    X_train, X_test, y_train, y_test = split_data(
+        X,
+        y,
+        test_size=test_pct,
+        problem_type=problem_type,
+        problem_configuration=problem_configuration,
+    )
     test_size = len(X) * test_pct
     train_size = len(X) - test_size
     assert len(X_train) == train_size
