@@ -22,7 +22,12 @@ class SKOptTuner(Tuner):
             random_seed (int): The seed for the random number generator. Defaults to 0.
         """
         super().__init__(pipeline_hyperparameter_ranges, random_seed=random_seed)
-        self.opt = Optimizer(self._search_space_ranges, "ET", acq_optimizer="sampling", random_state=random_seed)
+        self.opt = Optimizer(
+            self._search_space_ranges,
+            "ET",
+            acq_optimizer="sampling",
+            random_state=random_seed,
+        )
 
     def add(self, pipeline_parameters, score):
         """Add score to sample
@@ -41,14 +46,18 @@ class SKOptTuner(Tuner):
         try:
             self.opt.tell(flat_parameter_values, score)
         except Exception as e:
-            logger.debug('SKOpt tuner received error during add. Score: {}\nParameters: {}\nFlat parameter values: {}\nError: {}'
-                         .format(pipeline_parameters, score, flat_parameter_values, e))
+            logger.debug(
+                "SKOpt tuner received error during add. Score: {}\nParameters: {}\nFlat parameter values: {}\nError: {}".format(
+                    pipeline_parameters, score, flat_parameter_values, e
+                )
+            )
             if str(e) == "'<=' not supported between instances of 'int' and 'NoneType'":
-                msg = "Invalid parameters specified to SKOptTuner.add: parameters {} error {}" \
-                    .format(pipeline_parameters, str(e))
+                msg = "Invalid parameters specified to SKOptTuner.add: parameters {} error {}".format(
+                    pipeline_parameters, str(e)
+                )
                 logger.error(msg)
                 raise ParameterError(msg)
-            raise(e)
+            raise (e)
 
     def propose(self):
         """Returns a suggested set of parameters to train and score a pipeline with, based off the search space dimensions and prior samples.
@@ -57,7 +66,7 @@ class SKOptTuner(Tuner):
             dict: Proposed pipeline parameters
         """
         with warnings.catch_warnings():
-            warnings.simplefilter('ignore')
+            warnings.simplefilter("ignore")
             if not len(self._search_space_ranges):
                 return self._convert_to_pipeline_parameters({})
             flat_parameters = self.opt.ask()
